#![allow(dead_code)]
mod r#enum;
mod map_args;
mod r#struct;
mod struct_generic;
mod struct_map;
mod unit_enum;
mod unit_struct;
mod write;
